################################################################
## Script by T. Vu 
## Kaplan-Meier VPC
## Last updated NH 10 Jan 2021
## NH 31 August 2013
## Added ability to use awk to update script to run with
## different models and data sets
################################################################

rm(list=ls())
path <- "./"
setwd(path)
## set up functions
source("T2E_VPC_Functions.R")

## next lines may be updated by nmvpc2r.awk ( <- will be changed to = in output of awk )
eventName    <- "Major Bleed"
modelName    <- "modelName" 
obsFileName  <- "obsFileName"
CIpercent    <- 0.9   # confidence interval range
Ytick	       <- 0.1   # interval of probability tickmarks for y-axis (e.g., tick marks at every increment of 0.1)
Ymin         <- 0.0   # minimum scale for y-axis

timeScale 	 <- 1     # scale factor for original time scale to plot time scale
Xlabel       <- "days" # X-axis label on graph

# All x-values from here onwards refer to scaled values using timeScale
Xtick 	    <- 1     # interval of x-axis (e.g. tick marks at increment of 1 month)
Xmax 	       <- 12    # maximum scale for x-axis (e.g. 12 months)
simxlim      <- Xmax+Xtick  # plotting limit for simulated values (e.g., truncated simulated probabilities at 6 months)

binTimes 	 <- seq(0,13,0.5) #interpolation interval for simulated KM
pub 		    <- F
addLegend    <- T
figName      <- paste(modelName,"_",obsFileName,sep="")
figOutputDir <- "./"

#############################################
## read in observed and simulated data, produce obsFile and simFile objects
#############################################

simFile <- readData(paste(modelName,'.csv',sep=''))
#names(simFile) <-  c('ID','TIME','TRT','AMT','RATE','ADDL','II','WT','DVID','DV','MDV','REP,','CP','PCA','INR','CL','V','TABS','TLAG','PCA0','EMAX','C50','TEQ')
#write.csv(simFile,"simfile.csv") # for debugging
simFile$TIME <- simFile$TIME*timeScale # convert scale
names(simFile)[1]="ID" # simFile may use #ID in header

obsFile <- readData(paste(obsFileName,'.csv',sep=''))
#write.csv(obsFile,"obsfile.csv") # for debugging
obsFile$TIME <- obsFile$TIME*timeScale # convert scale
names(obsFile)[1]="ID" # obsFile may use #ID in header

if (eventName=="Death") {
   eventName="Survival"
} else {
   eventName=paste("No ",eventName,sep="")
}
ylabel	<- paste("Probability of ",eventName,sep="")
pCols 	<- c(obscol='black',simmed='blue',simpi='skyblue2')

timeScaleTxt=Xlabel # timeScaleTxt is used by plotKM()

#############################################
#### OBTAIN SURVIVAL CURVES, INTERPOLATE, & QUANTILES
#############################################
kmsurvout <- KMSurv(simFile)
# compute quantiles for KM estimates of simulated events
kmquantout <- KMSurvQuant(kmsurvout[!is.na(kmsurvout$SURV),])

#############################################
#### GENERATE PLOTS
#############################################
pdf(paste(figOutputDir,figName,".pdf",sep=''),height=8.5,width=11,paper="a4r")
#par(pin=c(4,3),omi=c(rep(0.2,2),0.1,0),xpd=F)
plotKM(kmquantout,obsFile)
dev.off()


