################################################################
## nmvpc2r
## Script by Nick Holford 
## modifies R scripts used by nmvpc and ttevpc
## Last updated NH 10 Jan 2021
################################################################

BEGIN {
   if (ARGS!="") {
      ok=getline < ARGS
      gsub(/\\/,"/")
      WFNHOME=$0
      ok=getline < ARGS
      if (ok>=1) {
         gsub(/\\/,"/")
         USER_THEME=$0
      } else {
         USER_THEME="user_theme.R"
      }
      close(ARGS)
   }
   DVID=DVID+0
   hasdvid=(DVID>0)
   if (NMCTL=="") NMCTL=".ctl"
}
#/source\(\"nmvpc_PKPD_Functions\.R\"/ {
#  print "source(\"" WFNHOME "/bin/nmvpc_PKPD_Functions.R" "\") ## set up functions"
#  next
#}

/^ *theme/ && THEME != "" {
   print "theme          =" tolower(THEME)
   next
}

/^ *USER_THEME/ {
   print "USER_THEME     = \"" USER_THEME "\" # source file for user theme options"
   next
}

/if \(ISWFN\) NMDIR/ && NMDIR != "" {
   print "if (ISWFN) NMDIR=\"" NMDIR "\""
   next
}

/^ *NMDIR/ && NMDIR != "" {
   print "NMDIR=\"" NMDIR "\""
   next
}

/^ *NMTBL/ && NMTBL != "" {
   print "NMTBL=\"" NMTBL "\""
   next
}

/^ *modelName/ {
   i=index(MODEL,NMCTL)
   if (i) MODEL=substr(MODEL,1,i-1)
   print "modelName = \"" MODEL "\""
   next
}
/^ *obsFileName/ {
   i=index(OBSFILE,NMCTL)
   if (i) OBSFILE=substr(OBSFILE,1,i-1)
   print "obsFileName = \"" OBSFILE "\""
   next
}
/^ *thisDVID/ {
   print "thisDVID = " DVID
   next
}

/^ *hasDVID/ {
   if (hasdvid)
      print "hasDVID = T"
   else
      print "hasDVID = F"
   next
}

/^ *logaxis/ {
   print "logaxis = \"" LOGAXIS "\""
   next
}
/^ *Ymin/ && !/Ymax/{
   print "Ymin = " YMIN
   next
}
/^ *LLOQ/ {
   if (LLOQ==".") LLOQ="\".\""
   print "LLOQ = " LLOQ
   next
}

/^ *Ymax/ {
   print "Ymax = " YMAX
   next
}
/^ *Ytick/ {
   print "Ytick = " YTICK
   next
}
/^ *Ylabel/ && YLABEL!="" {
   gsub(/#/," ",YLABEL)
   print "   Ylabel = \"" YLABEL "\""
   next
}

/^ *pcYlabel/ {
   gsub(/#/," ",pcYLABEL)
   print "   Ylabel = \"" YLABEL " [pc]\""
   next
}

/^ *Xmin/ && !/Xmax/ {
   print "Xmin = " XMIN
   next
}
/^ *Xmax/ {
   print "Xmax = " XMAX
   next
}
/^ *Xtick/ {
   print "Xtick = " XTICK
   next
}
/^ *Xlabel/ && XLABEL!="" {
   gsub(/#/," ",XLABEL)
   print "Xlabel = \"" XLABEL "\""
   next
}
/^ *binTimes/ {
   print "binTimes = c(" BINTIMES")"
   next
}

/^ *yScale/ {
   if (YSCALE=="") YSCALE=1
   print "yScale = c(" YSCALE ")"
   next
}

#Do not change the next line!
#SELECT specific observations e.g. study number
#obsFile = obsFile[obsFile$SDY==1,]
#simFile = simFile[simFile$SDY==1,]

/^#SELECT/ && SELECT!="" {
#print "SELECT=|"SELECT"|"
   iand= match(toupper(SELECT),/\.AND\./)
   if (iand)
      SELECTOBS=substr(SELECT,1,iand-1) " & obsFile$"  substr(SELECT,iand+5)
   else
      SELECTOBS=SELECT
   print "obsFile = obsFile[obsFile$"SELECTOBS",]"
   if (iand) 
      SELECTSIM=substr(SELECT,1,iand-1) " & simFile$"  substr(SELECT,iand+5)
   else
      SELECTSIM=SELECT
   print "simFile = simFile[simFile$"SELECTSIM",]"
   next
}

/^ *pdfTxt/ && PDFTXT!="" {
   gsub(/#/,"_",PDFTXT)
   print "pdfTxt = \"" PDFTXT "\""
   next
}

/^ *figOutputDir/ && FIGDIR!="" {
   print "figOutputDir = \"" FIGDIR ".pdf/\""
   next
}

/^ *isCSV/ && ISCSV!="" {
   if (index(toupper(ISCSV),"Y"))
      isCSV="T"
   else if (ISCSV+0>0)
      isCSV="T"
   else
      isCSV="F"
   print "isCSV = "isCSV
   next
}

/^ *isPC/ && ISPC!="" {
   if (index(toupper(ISPC),"Y"))
      isPC="T"
   else if (ISPC+0>0)
      isPC="T"
   else
      isPC="F"
   print "isPC = "isPC
   next
}

/^ *isOBS/ && ISOBS!="" {
   if (index(toupper(ISOBS),"Y"))
      isOBS="T"
   else if (ISOBS+0>0)
      isOBS="T"
   else
      isOBS="F"
   print "isOBS = "isOBS
   next
}

/^ *CIpercentile/ {
   print "CIpercentile = " CIPCT
   next
}
/^ *PIplotCI/ && PIPLOTCONFINT!="" {
   if (index(toupper(PIPLOTCONFINT),"N"))
      PIplotCI="F"
   else if (index(toupper(PIPLOTCONFINT),"Y"))
      PIplotCI="T"
   else
      PIplotCI="T"
   print "PIplotCI = "PIplotCI
   next
}

/^ *PIpercentile/ {
   print "PIpercentile = " PIPCT
   next
}

/^ *SplotPredInt/ {
   if (index(toupper(SPLOTPREDINT),"N"))
      SplotPredInt="F"
   else if (SPLOTPREDINT+0>0)
      SplotPredInt="T"
   else
      SplotPredInt="T"
   print "SplotPredInt = "SplotPredInt
   next
}
/^ *PIplotPredInt/ {
   if (index(toupper(PIPLOTPREDINT),"N"))
      PIplotPredInt="F"
   else if (PIPLOTPREDINT+0>0)
      PIplotPredInt="T"
   else
      PIplotPredInt="T"
   print "PIplotPredInt = "PIplotPredInt
   next
}
/^ *SplotObsInt/ {
   if (index(toupper(SPLOTOBSINT),"N"))
      SplotObsInt="F"
   else if (SPLOTOBSINT+0>0)
      SplotObsInt="T"
   else
      SplotObsInt="T"
   print "SplotObsInt = "SplotObsInt
   next
}

/^ *PIplotObsInt/ {
   if (index(toupper(PIPLOTOBSINT),"N"))
      PIplotObsInt="F"
   else if (PIPLOTOBSINT+0>0)
      PIplotObsInt="T"
   else
      PIplotObsInt="T"
   print "PIplotObsInt = "PIplotObsInt
   next
}

/^ *plotObsNotch/ {
   if (index(toupper(PLOTOBSNOTCH),"N"))
      plotObsNotch="F"
   else if (PLOTOBSNOTCH+0>0)
      plotObsNotch="T"
   else
      plotObsNotch="T"
   print "plotObsNotch= "plotObsNotch
   next
}

/^ *showbins/ {
   if (index(toupper(SHOWBINS),"N"))
      showbins="F"
   else if (SHOWBINS+0>0)
      showbins="T"
   else
      showbins="T"
   print "showbins= "showbins
   next
}

/^ *PIplotsymbols/ {
   if (index(toupper(PIPLOTSYMBOLS),"N")) {
      PIplotsymbols="F"
      PIplotid="F"}
   else if (index(toupper(PIPLOTSYMBOLS),"Y")) {
      PIplotsymbols="T"
      PIplotid="F"}
   else if (index(toupper(PIPLOTSYMBOLS),"ID")) {
      PIplotsymbols="F"
      PIplotid="T"}
   else {
      PIplotsymbols="F"
      PIplotid="F"}
   print "PIplotsymbols= "PIplotsymbols
   print "PIplotid= "PIplotid
   next
}

/^ *Splotsymbols/ {
   if (index(toupper(SPLOTSYMBOLS),"N")) {
      Splotsymbols="F"
      Splotid="F"}
   else if (index(toupper(SPLOTSYMBOLS),"Y")) {
      Splotsymbols="T"
      Splotid="F"}
   else if (index(toupper(SPLOTSYMBOLS),"ID")) {
      Splotsymbols="F"
      Splotid="T"}
   else {
      Splotsymbols="T"
      Splotid="F"}
   print "Splotsymbols= "Splotsymbols
   print "Splotid= "Splotid
   next
}

/^ *Splotspaghetti/ {
   if (index(toupper(SPLOTSPAGHETTI),"N"))
      Splotspaghetti="F"
   else if (index(toupper(SPLOTSPAGHETTI),"Y"))
      Splotspaghetti="T"
   else
      Splotspaghetti="F"
   print "Splotspaghetti= "Splotspaghetti
   next
}

/^ *showlegend/ {
   if (index(toupper(SHOWLEGEND),"A")) {
      showlegendabove="T"
      showlegendbelow="F"
   } else if (index(toupper(SHOWLEGEND),"B")) {
      showlegendabove="F"
      showlegendbelow="T"
   } else {
      showlegendabove="F"
      showlegendbelow="F"
   }
   print "showlegendabove= "showlegendabove
   print "showlegendbelow= "showlegendbelow
   next
}

/^ *isSTD/ && ISSTD!="" {
   if (index(toupper(ISSTD),"N"))
      isSTD="F"
   else if (ISSTD+0>0)
      isSTD="T"
   else
      isSTD="T"
   print "isSTD = "isSTD
   next
}

/^ *isSTD/ && ISSTD!="" {
   if (index(toupper(ISSTD),"N"))
      isSTD="F"
   else if (ISSTD+0>0)
      isSTD="T"
   else
      isSTD="T"
   print "isSTD = "isSTD
   next
}

/^ *isNEW/ && ISNEW!="" {
   if (index(toupper(ISNEW),"Y"))
      isNEW="T"
   else if (ISNEW+0>0)
      isNEW="T"
   else
      isNEW="F"
   print "isNEW = "isNEW
   next
}

/^ *isBIG/ && ISBIG!="" {
   if (index(toupper(ISBIG),"Y"))
      isBIG="T"
   else if (ISBIG+0>0)
      isBIG="T"
   else
      isBIG="F"
   print "isBIG = "isBIG
   next
}

#/^ *timeScale/ {
#   print "timeScale = c(" TIMESCALE ")"
#   next
#}

/^ *timeScale / && TIMESCALE!="" {
   print "timeScale = "TIMESCALE
   next
}

/^ *simFile\$TIME\=simFile\$TIME\*timeScale/ && TIMENAME!="" {
   print "   simFile$TIME=simFile$"TIMENAME"*timeScale"
   next
}

/^ *hasMDV/ && HASMDV!="" {
   if (index(toupper(HASMDV),"Y"))
      hasMDV="T"
   else if (HASMDV+0>0)
      hasMDV="T"
   else
      hasMDV="F"
   print "hasMDV = "hasMDV
   next
}

/simFile\$MDV/ && MDVPNAME!="" {
   gsub(/simFile\$MDV/,"simFile$"MDVPNAME)
   print
   next
}

/^ *dvPname/ && DVPNAME!="" {
   $0="dvPname=" "'" DVPNAME "'" 
   print
   next
}

/^ *obsName/ && OBSPNAME!="" {
   $0="obsName=" "'" OBSPNAME "'"
   print
   $0="obsFile$OBS=obsFile$" OBSPNAME
   print
   next
}

{print}

