@echo off
if not '%1==' goto %1
rem ************************************************************************************
rem ***** This section has variables which may be changed to explore T2E models *****
rem ************************************************************************************
rem set runNONMEM=y to execute nmgosim to simulate events
set runNONMEM=n

rem set NREP=1 for simple demonstration. set NREP=10 or more for VPC
set NREP=100
rem set NSUB to number of subjects in each replication
set NSUB=100
rem NVPC specifies the number of repeats of VPC with different simulated 'observation' data sets eg. must be <= NREP (default=1)
set NVPC=10

rem Name of csv file containing observed event data (must set runest=onlysim)
set obsdat=warf_INR_OBS
rem set runest=onlysim to use observed event data and simulate replicates for VPC
rem set to name of NM-TRAN control stream to simulate observed data, simulate replicates for VPC and estimate parameters from simulated replicates 
rem set runest= to run all estimation models that match the pattern *est%NMCTL% 
rem set runest=
rem set runest=onlyvpc to run VPC only (assumes data has already been simulated)
set runest=onlyvpc
rem Name of NM-TRAN control stream to simulate events
rem set runsim=warf_INR_sim
rem Name of awk script to extract tte data from each replication of simulated data
set make_t2e_awk=make_t2e.awk

rem xname defines the independent variable name in the data (usually TIME)
set xname=TIME
rem timescale may change plot time scale e.g. 1/28 to change days to months
set timescale=1/28
rem xlabel identifies units on plot time axis
set xlabel=months
rem ymin sets lower bound of plot survivor function axis
set ymin=0.5
rem drug identifier
set rundrug=warf

rem **********************************
rem ***** Advanced user settings *****
rem **********************************


rem DVID used to signal start of censored event interval in %make_t2e_awk%. Use startdvid=0 to signal a censored event at the start of the interval.
set startdvid=3
rem OBSINT determines the censoring interval for events
set OBSINT=1
rem simdat.awk creates a NONMEM input data file for simulating at many times for each subject
rem If ALL=Y additional records are created to simulate biomarkers such as CONC and PCA (ALL=Y can be used for debugging)
set all=

rem options for use when running NONMEM on a grid cluster
rem set grid=g to execute nmgog 
set grid=
set args7=
set cpus=

rem ************************************************************************************
rem ***** Do not change below here unless you are sure you know what you are doing *****
rem ************************************************************************************

rem ctsthisgotdata is used by nmgosim
if '%runNONMEM%=='y set ctsthisgotdata=n
if '%runNONMEM%=='Y set ctsthisgotdata=n
if '%runNONMEM%=='n set ctsthisgotdata=y
if '%runNONMEM%=='N set ctsthisgotdata=y
if '%ctsthisgotdata%=='y goto dotypes

rem Create data template for simulation
@echo Creating data template for simulation ...
@echo on
%nmawk% -f simdat.awk -v NCYCLE= -v CYCLEINT= -v II=1 -v NREP=1 -v NSUB=%NSUB% -v TLAST=365 -v OBSINT=%OBSINT% -v ALL=%all%  > data.csv
@echo off

:dotypes
rem types specifies a list of one or more hazard covariate types for simulation
set types=INR
for %%t in (%types%) do call %0 type %%t
goto over

:type
set runtype=%2
set runobs=%rundrug%_%runtype%

rem create simulation output file name
if '%runsim%==' set runsim=%runobs%_sim
rem The following are used by nmgosim
set onlysim=%runsim%_onlysim
rem Rebuild predpp for simulation by setting args7_sim=
set args7_sim=
rem awk script to extract T2E data from NONMEM simulation table file
set fixdat=..\%make_t2e_awk%
rem fixdat works on the csv file created by nmgosim
set fixarg=-v ALL=%all% -v DELTA=0 -v INTERVAL=mid -v STARTDVID=%startdvid% -v IFS=,
rem NSUBPROBLEM sets number of sub-problems (replications) in simulation control file
rem NM7.4 and later may use $SIM REWIND option to avoid problems caused by transgeneration from one sub-problem to the next
rem if NSUBPROBLEM is more than 1
set NSUBPROBLEM=%NREP%

rem Avoid PREDPP compilation for estimation models
set args7=-prdefault
if "%runest%"=="onlysim" (
   call %0 gosim %onlysim%%NMCTL%
   call %0 mkvpc
   goto over
)
if "%runest%"=="onlyvpc" (
   call %0 mkvpc
   goto over
)
if "%runest%"=="" (
   set runest=%rundrug%_*est*%NMCTL%
) else (
   set runest=%runest%%NMCTL%
)
rem Simulate (before first model) and run each estimation model
@echo on
for %%f in (%runest%) do call %0 gosim %%f
@echo off
if not exist %runsim%%NMDIR%\%NREP%.csv goto simerror
rem Prepare estimation folders for nmobj and nmmbt
call nmretbl

:mkvpc
rem Finish up for each type by creating KM plot for typical observations and for VPC
set tmpnvpc=1
rem Only do simulated sample 'observed' VPCs if there is no actual observed data
if not'%runest%=='onlysim set tmpnvpc=%NVPC%
if not exist %runsim%%NMDIR%\%tmpnvpc%.csv goto simerror
@echo off

set simulated_obs=
if not '%runest%=='onlysim set simulated_obs=and %tmpnvpc% sample 'observed' data sets
@echo Create Kaplan-Meier plot with %NREP% replications %simulated_obs%...

rem Sample observation data set
@ echo off
rem OBSFILE single for KM plot
copy %runsim%%NMDIR%\1.csv %runobs%1.csv>nul
rem MODEL VPC data set for Kaplan-Meier
copy %runsim%%NMDIR%\1.csv %runobs%_%NREP%.csv>nul
for /L %%C in (2,1,%NREP%) do %nmawk% "NR!=1" %runsim%%NMDIR%\%%C.csv >> %runobs%_%NREP%.csv
rem Call vpc subroutine
for /L %%C in (1,1,%tmpnvpc%) do call %0 vpc %%C
@echo off
if exist .Rdata del .Rdata
set tmpnvpc=
goto over

rem VPC subroutine for treatment KM and VPC KM plots
:vpc
@echo off
if not '%runest%=='onlysim (
   copy %runsim%%NMDIR%\%2.csv %runobs%%2.csv>nul
) else (
   if not exist %obsdat%.csv goto obserror
   copy %obsdat%.csv %runobs%%2.csv>nul
)
@echo VPC OBSFILE=%runobs%%2 MODEL=%runobs%_%NREP%

set tmp_t2efigdir=%rundrug%_KM_OBS
if not exist %tmp_t2efigdir%.pdf/nul md %tmp_t2efigdir%.pdf
%nmawk% -f nmvpc2r.awk -v OBSFILE=%runobs%%2 -v YMIN=%ymin% -v YTICK=0.05 -v TIMENAME=%xname% -v TIMESCALE=%timescale% -v XLABEL=%xlabel%  -v XMAX=12 -v XTICK=1 -v FIGDIR=%tmp_t2efigdir% T2E_OBS.R>tmp_obs.R
rcmd BATCH tmp_obs.R
if not exist %tmp_t2efigdir%.pdf\%runobs%%2.pdf echo Error in %0: VPC OBS %tmp_t2efigdir%\%runobs%%2.pdf does not exist

set tmp_t2efigdir=%rundrug%_KM_VPC
if not exist %tmp_t2efigdir%.pdf/nul md %tmp_t2efigdir%.pdf
%nmawk% -f nmvpc2r.awk -v OBSFILE=%runobs%%2 -v YMIN=%ymin% -v YTICK=0.05 -v TIMENAME=%xname% -v TIMESCALE=%timescale% -v XLABEL=%xlabel% -v XMAX=12 -v XTICK=1 -v FIGDIR=%tmp_t2efigdir% -v MODEL=%runobs%_%NREP% -v CIPCT=0.95 -v BINTIMES=seq(0,13,0.5) T2E_VPC.R>tmp_vpc.R
rcmd BATCH tmp_vpc.R
if not exist %tmp_t2efigdir%.pdf\%runobs%_%NREP%_%runobs%%2.pdf echo Error in %0: VPC MODEL %tmp_t2efigdir%\%runobs%_%NREP%_%runobs%%2.pdf does not exist

if exist %runobs%%2.csv del %runobs%%2.csv
set tmp_t2efigdir=
goto over

rem Simulation subroutine for simulation (first call) and running each estimation model
:gosim
@echo off
if not '%runest%=='onlysim if not exist %2 goto esterror
if '%ctsthisgotdata%==' set ctsthisgotdata=n
if '%ctsthisgotdata%=='N set ctsthisgotdata=n
if '%ctsthisgotdata%=='n (
   rem Simulate data and keep after estimation
   set ctsthisgotdata=n
   rem Replace raw simulated .csv with transformed data by setting gotsampascsv=n
   set gotsampascsv=n
   rem Remove previous simulated data
   if exist %runobs%.csv del %runobs%.csv
   if exist %runobs%_%NREP%.csv del %runobs%_%NREP%.csv
) else (
   rem Use previously simulated data
   set ctsthisgotdata=y
   rem Use transformed data .csv
   set gotsampascsv=y
   if '%runest%=='onlysim goto over
)
@echo off

@echo %2 ctsthisgotdata=%ctsthisgotdata% gotsampascsv=%gotsampascsv%
rem Dummy onlysim.ctl to allow nmgosim to be reached after nmcmd.bat call to nmbscheck.bat
if '%runest%=='onlysim echo %2>%onlysim%%NMCTL%
@echo on
call nmgosim %runsim% %2 1 %NREP%
@echo off
if exist %onlysim%%NMCTL% del %onlysim%%NMCTL%
rem Use previously simulated data
set ctsthisgotdata=y
rem Use transformed data .csv
set gotsampascsv=y

goto over

:simerror
if not exist %runsim%%NMDIR%\%NREP%.csv echo Error in %0: %runsim%%NMDIR%\%NREP%.csv does not exist
goto over

:obserror
if not exist %obsdat% echo Error in %0: %obsdat% does not exist
goto over

:esterror
if not exist %2 echo Error in %0: %2 does not exist
goto over

:over
if exist _tmp.bat del _tmp.bat

