################################################################
## Script by Nick Holford 
## Kaplan-Meier Plot
## Last updated NH 10 Jan 2021
################################################################

library(survival)

rm(list=ls())
path <- "./"
figOutputDir <- "./"
setwd(path)

## next lines may be updated by nmvpc2r.awk ( <- will be changed to = in output of awk )
eventName    <- "Major Bleed"
modelName    <- "modelName" 
obsFileName  <- "obsFileName"
CIpercent    <- 0.9   # confidence interval range
Ytick	       <- 0.1   # interval of probability tickmarks for y-axis (e.g., tick marks at every increment of 0.1)
Ymin         <- 0.0   # minimum scale for y-axis

timeScale 	 <- 1     # scale factor for original time scale to plot time scale
Xlabel       <- "days" # X-axis label on graph

# All x-values from here onwards refer to scaled values using timeScale
Xtick 	    <- 1     # interval of x-axis (e.g. tick marks at increment of 1 month)
Xmax 	       <- 12    # maximum scale for x-axis (e.g. 12 months)
simxlim      <- Xmax+Xtick  # plotting limit for simulated values (e.g., truncated simulated probabilities at 6 months)

interpfreq 	 <- seq(0,12,by=0.5) #interpolation interval for simulated KM (e.g. 0,12 by 0.5 months) 

ispdf=1
figOutputDir <- "./"
figName      <- obsFileName

####################### Read observation file and create KM plots by TRT group #########

obsFile=read.csv(paste(obsFileName,".csv",sep=""),stringsAsFactors=F)
names(obsFile)[1]="ID" # obsFile may use #ID in header
obsFile$TIME <- obsFile$TIME*timeScale # convert scale

event <- subset(obsFile, MDV==0, select=c("ID","TIME","DV","TRT"))
event[,"DV"] <- as.numeric(event[,"DV"])
if (ispdf) {
pdf(paste(figOutputDir,figName,".pdf",sep=''),height=8.5,width=11,paper="a4r")
}

fit1 <- survfit(Surv(TIME,DV)~TRT, data=event,conf.type="none")

if (eventName=="Death") {
   eventName="Survival"
} else {
   eventName=paste("No ",eventName,sep="")
}
ylabel	<- paste("Probability of ",eventName,sep="")

xscale <- c(0,Xmax); yscale <- c(Ymin,1)
kmcolors=c("black","blue","green","red")
kmplot=plot(fit1, 
   col=kmcolors, cex.main=1, 
   ylim=yscale, xlim=xscale,
   mark.time=TRUE
)
mtext(side=1, line=2,paste("Time since study entry (",Xlabel,")",sep=''),cex=1.25)
mtext(side=2, line=2,paste(ylabel),cex=1.25)
mtext(side=4,line=.5,cex=0.5,adj=.5,paste("obsFile:",obsFileName,"\n simFile:",modelName,sep=''))
legend( 
    legend = c("0 mg/d","2.5 mg/d","5 mg/d","10 mg/d"), 
    lty=c(1,1,1,1),lwd=c(2,2,2,2),
    col=kmcolors, bty='n', cex=1,
    x=0.01*Xmax,y=Ymin+(1-Ymin)*0.35
)
if (ispdf) {
   print(kmplot)
   dev.off()
}


#nevent <- length(unique(event$ID[event$DV==1]))
#ncens <- length(unique(event$ID[event$DV!=1]))
#fitcox <- coxph(Surv(TIME,DV)~TRT, data=event)
#plot( survfit( fitcox))
